@@ -6,16 +6,18 @@ from aiogram.utils.magic_filter import MagicFilter
 
 Markup = Union[types.ReplyKeyboardMarkup, types.InlineKeyboardMarkup]
 FormFilter = Union[MagicFilter, Callable[..., Awaitable[Any]]]
+
+# TODO: pass di data into enter callback
 EnterCallback = Callable[[int, int, "FormFieldData"], Awaitable[Any]]
 
 
 @dataclass(frozen=True)
 class FormFieldInfo:
-    enter_message_text: str | None
+    enter_message_text: Optional[str]
     error_message_text: Optional[str]
     filter: Optional[FormFilter]
     reply_markup: Optional[Markup]
-    enter_callback: EnterCallback | None
+    enter_callback: Optional[EnterCallback]
 
 
 @dataclass
@@ -27,11 +29,11 @@ class FormFieldData:
 
 def FormField(
     *,
-    enter_message_text: str | None = None,
+    enter_message_text: Optional[str] = None,
     filter: Optional[FormFilter] = None,
     error_message_text: Optional[str] = None,
     reply_markup: Optional[Markup] = None,
-    enter_callback: EnterCallback | None = None
+    enter_callback: Optional[EnterCallback] = None
 ) -> Any:
     if enter_message_text is None and enter_callback is None:
         raise ValueError("enter_message_text or enter_callback should be set")
